.. Copyright (C) 2013-2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.nfs`` Ansible role can be used to configure NFS shares on
Debian/Ubuntu hosts.
